@@ -20,7 +20,7 @@ class Mongo:
         secret_access_key = quote_plus(aws_secret_access_key)
         cluster = quote_plus(mongo_cluster)
 
-        uri = "mongodb+srv://%s:%s@%s/?authSource=$external&authMechanism=MONGODB-AWS&retryWrites=true&w=majority" % (
+        uri = "mongodb+srv://%s:%s@%s/?authSource=$external&authMechanism=MONGODB-AWS&retryWrites=true&w=majority&readConcernLevel=majority&readPreference=secondaryPreferred" % (
             access_key_id,
             secret_access_key,
             cluster,
