@@ -14,6 +14,7 @@ from sagemaker.feature_store.feature_definition import (
 from sagemaker.session import Session
 from sagemaker import get_execution_role
 from sagemaker.feature_store.feature_group import AthenaQuery, FeatureGroup
+from sagemaker.feature_store.inputs import FeatureValue
 from pyspark.sql import DataFrame as SparkDataFrame
 from concurrent.futures import ThreadPoolExecutor
 from concurrent.futures import as_completed
@@ -443,6 +444,49 @@ class SagemakerFeatureStore:
                 f'\nInserting data to "{feature_group_name}" is running in background..'
             )
 
+    def ingest_stream(
+        self,
+        feature_group_name: str,
+        record: FeatureValue,
+    ):
+        """
+        Puts a single record in the FeatureGroup
+
+        Parameters
+        ----------
+        feature_group_name : str, required
+            Name of the Feature Group
+
+        record : List, required
+            List containing the feature values, each element should be in dict form :
+
+                {feature_name: str, value_as_string: str}
+
+                where:
+                    feature_name : name of the Feature
+
+                    value_as_string : value of the Feature in string form
+
+        Returns
+        -------
+        None
+        """
+
+        print(f'\nStarted ingesting stream data for "{feature_group_name}"..')
+        region = "ap-southeast-1"
+        os.environ["AWS_DEFAULT_REGION"] = region
+        session = boto3.session.Session()
+        runtime = session.client(
+            service_name="sagemaker-featurestore-runtime",
+            config=Config(retries={"max_attempts": 10, "mode": "standard"}),
+        )
+
+        resp = runtime.put_record(FeatureGroupName=feature_group_name, Record=record)
+        if not resp["ResponseMetadata"]["HTTPStatusCode"] == 200:
+            raise (f"PutRecord failed: {resp}")
+
+        print(f'\nSuccessfully inserted data to "{feature_group_name}"')
+
     def ingest_spark_df(
         self,
         feature_group_name: str,
@@ -987,3 +1031,29 @@ if __name__ == "__main__":
     #     enable_online_store=True,
     #     enable_offline_store=True,
     # )
+
+    # feature_group_name = 'customers-feature-group-16-07-38-24'
+
+    # record = [
+    #     {
+    #         'FeatureName':'customer_id',
+    #         'ValueAsString':'012313'
+    #     },
+    #     {
+    #         'FeatureName':'city_code',
+    #         'ValueAsString':'321'
+    #     },
+    #     {
+    #         'FeatureName':'state_code',
+    #         'ValueAsString':'32'
+    #     },
+    #     {
+    #         'FeatureName':'country_code',
+    #         'ValueAsString':'1234'
+    #     },
+    #     {
+    #         'FeatureName':'EventTime',
+    #         'ValueAsString':str(int(round(time.time())))
+    #     }
+    # ]
+    # feature_store.ingest_stream(feature_group_name, record)
